@@ -6,7 +6,7 @@ __author__ = "Sergio J. Rey <sjsrey@gmail.com>"
 
 __all__ = ["Rose"]
 
-import warnings
+
 import numpy as np
 from libpysal import weights
 from libpysal.common import requires as _requires
@@ -17,7 +17,7 @@ _NEG8 = 1 - _POS8
 _NEG4 = 1 - _POS4
 
 
-class Rose(object):
+class Rose:
     """
     Rose diagram based inference for directional LISAs.
 
@@ -27,7 +27,8 @@ class Rose(object):
     Parameters
     ----------
     Y : array (n,2)
-        Columns correspond to end-point time periods to calculate LISA vectors for n object.
+        Columns correspond to end-point time periods to
+        calculate LISA vectors for n object.
     w : PySAL W
         Spatial weights object.
     k : int
@@ -199,7 +200,12 @@ class Rose(object):
         rose diagram conditional on the starting relative income:
 
         >>> fig1, _ = r8.plot(attribute=Y[:,0])
-        >>> plt.show()
+        >>> plt.show(block=False)
+
+        Close plot when finished viewing.
+
+        >>> plt.close("all")
+
         """
 
         self.Y = Y
@@ -291,7 +297,7 @@ class Rose(object):
             P = NEG * L + (1 - NEG) * S
             self.p = P
         else:
-            print(("Bad option for alternative: %s." % alternative))
+            print("Bad option for alternative: %s." % alternative)
 
     def _calc(self, Y, w, k):
         wY = weights.lag_spatial(w, Y)
@@ -349,10 +355,8 @@ class Rose(object):
         Plot vectors of positional transition of LISA values starting
         from the same origin.
         """
-        import matplotlib.cm as cm
         import matplotlib.pyplot as plt
 
-        ax = plt.subplot(111)
         xlim = [self._dx.min(), self._dx.max()]
         ylim = [self._dy.min(), self._dy.max()]
         for x, y in zip(self._dx, self._dy):
