@@ -5,10 +5,12 @@ __author__ = "Sergio J. Rey <sjsrey@gmail.com>, Wei Kang <weikang9009@gmail.com>
 
 __all__ = ["steady_state", "var_mfpt_ergodic", "mfpt"]
 
+from warnings import warn
+
 import numpy as np
 import numpy.linalg as la
 import quantecon as qe
-from warnings import warn
+
 from .util import fill_empty_diagonals
 
 
@@ -122,7 +124,9 @@ def steady_state(P, fill_empty_classes=False):
     >>> steady_state(p, fill_empty_classes = False)
     Traceback (most recent call last):
         ...
-    ValueError: Input transition probability matrix has 1 rows full of 0s. Please set fill_empty_classes=True to set diagonal elements for these rows to be 1 to make sure the matrix is stochastic.
+    ValueError: Input transition probability matrix has 1 rows full of 0s. \
+Please set fill_empty_classes=True to set diagonal elements for these \
+rows to be 1 to make sure the matrix is stochastic.
 
     """
 
@@ -148,8 +152,11 @@ def steady_state(P, fill_empty_classes=False):
 
 
 def _fmpt_ergodic(P):
-    warn('_fmpt_ergodic is deprecated. It will be replaced in giddy 2.5 with _mfpt_',
-         DeprecationWarning, stacklevel=2)
+    warn(
+        "_fmpt_ergodic is deprecated. It will be replaced in giddy 2.5 with _mfpt_",
+        DeprecationWarning,
+        stacklevel=2,
+    )
     return _mfpt_ergodic(P)
 
 
@@ -198,23 +205,26 @@ def _mfpt_ergodic(P):
     k = P.shape[0]
     A = np.zeros_like(P)
     ss = _steady_state_ergodic(P)
-    for i in range(k):
-        A[:, i] = ss
+    for j in range(k):
+        A[:, j] = ss
     A = A.transpose()
-    I = np.identity(k)
-    Z = la.inv(I - P + A)
+    i = np.identity(k)
+    Z = la.inv(i - P + A)
     E = np.ones_like(Z)
     A_diag = np.diag(A)
     A_diag = A_diag + (A_diag == 0)
     D = np.diag(1.0 / A_diag)
     Zdg = np.diag(np.diag(Z))
-    M = (I - Z + E.dot(Zdg)).dot(D)
+    M = (i - Z + E.dot(Zdg)).dot(D)
     return M
 
 
 def fmpt(P, fill_empty_classes=False):
-    warn('fmpt is deprecated. It will be replaced in giddy 2.5 with mfpt',
-         DeprecationWarning, stacklevel=2)
+    warn(
+        "fmpt is deprecated. It will be replaced in giddy 2.5 with mfpt",
+        DeprecationWarning,
+        stacklevel=2,
+    )
     return mfpt(P, fill_empty_classes)
 
 
@@ -286,7 +296,9 @@ def mfpt(P, fill_empty_classes=False):
     >>> mfpt(p, fill_empty_classes=False)
     Traceback (most recent call last):
         ...
-    ValueError: Input transition probability matrix has 1 rows full of 0s. Please set fill_empty_classes=True to set diagonal elements for these rows to be 1 to make sure the matrix is stochastic.
+    ValueError: Input transition probability matrix has 1 rows full of 0s. \
+Please set fill_empty_classes=True to set diagonal elements for these \
+rows to be 1 to make sure the matrix is stochastic.
     """
 
     P = np.asarray(P)
@@ -319,20 +331,19 @@ def mfpt(P, fill_empty_classes=False):
             try:
                 m[none0] = np.linalg.solve(p_calc, b)
             except np.linalg.LinAlgError as err:
-                if "Singular matrix" in str(err):
-                    if (row0 == 0).sum() > 0:
-                        index0 = set(np.argwhere(row0 == 0).flatten())
+                if "Singular matrix" in str(err) and (row0 == 0).sum() > 0:
+                    index0 = set(np.argwhere(row0 == 0).flatten())
+                    x = (p_calc[:, list(index0)] != 0).sum(axis=1)
+                    setx = set(np.argwhere(x).flatten())
+                    while not setx.issubset(index0):
+                        index0 = index0.union(setx)
                         x = (p_calc[:, list(index0)] != 0).sum(axis=1)
                         setx = set(np.argwhere(x).flatten())
-                        while not setx.issubset(index0):
-                            index0 = index0.union(setx)
-                            x = (p_calc[:, list(index0)] != 0).sum(axis=1)
-                            setx = set(np.argwhere(x).flatten())
-                        none0 = np.asarray(list(set(none0).difference(index0)))
-                        if len(none0) >= 1:
-                            p_calc = p_calc[none0, :][:, none0]
-                            b = b[none0]
-                            m[none0] = np.linalg.solve(p_calc, b)
+                    none0 = np.asarray(list(set(none0).difference(index0)))
+                    if len(none0) >= 1:
+                        p_calc = p_calc[none0, :][:, none0]
+                        b = b[none0]
+                        m[none0] = np.linalg.solve(p_calc, b)
             recc = (
                 np.nan_to_num(
                     (np.delete(P, desti, 1)[desti] * m), 0, posinf=np.inf
@@ -346,8 +357,14 @@ def mfpt(P, fill_empty_classes=False):
 
 
 def var_fmpt_ergodic(p):
-    warn('var_fmpt_ergodic is deprecated. It will be replaced in giddy 2.5 with var_fmpt_ergodic',
-         DeprecationWarning, stacklevel=2)
+    warn(
+        (
+            "var_fmpt_ergodic is deprecated. It will be "
+            "replaced in giddy 2.5 with var_fmpt_ergodic"
+        ),
+        DeprecationWarning,
+        stacklevel=2,
+    )
     return var_mfpt_ergodic(p)
 
 
@@ -389,13 +406,13 @@ def var_mfpt_ergodic(p):
     k = P.shape[0]
     A = _steady_state_ergodic(P)
     A = np.tile(A, (k, 1))
-    I = np.identity(k)
-    Z = la.inv(I - P + A)
+    i = np.identity(k)
+    Z = la.inv(i - P + A)
     E = np.ones_like(Z)
     D = np.diag(1.0 / np.diag(A))
     Zdg = np.diag(np.diag(Z))
-    M = (I - Z + E.dot(Zdg)).dot(D)
+    M = (i - Z + E.dot(Zdg)).dot(D)
     ZM = Z.dot(M)
     ZMdg = np.diag(np.diag(ZM))
-    W = M.dot(2 * Zdg.dot(D) - I) + 2 * (ZM - E.dot(ZMdg))
+    W = M.dot(2 * Zdg.dot(D) - i) + 2 * (ZM - E.dot(ZMdg))
     return np.array(W - np.multiply(M, M))
