@@ -15,19 +15,20 @@ __all__ = [
     "GeoRank_Markov",
 ]
 
+import itertools
+from operator import gt
+
+import mapclassify as mc
 import numpy as np
-from .ergodic import steady_state, mfpt
-from .util import fill_empty_diagonals
-from .components import Graph
-from warnings import warn
+import quantecon as qe
+from esda.moran import Moran_Local
+from libpysal import weights
 from scipy import stats
 from scipy.stats import rankdata
-from operator import gt
-from libpysal import weights
-from esda.moran import Moran_Local
-import mapclassify as mc
-import itertools
-import quantecon as qe
+
+from .components import Graph
+from .ergodic import mfpt, steady_state
+from .util import fill_empty_diagonals
 
 # TT predefine LISA transitions
 # TT[i,j] is the transition type from i to j
@@ -62,7 +63,7 @@ for i, sig_key in enumerate(sig_keys):
             c += 1
 
 
-class Markov(object):
+class Markov:
     """
     Classic Markov Chain estimation.
 
@@ -240,8 +241,8 @@ class Markov(object):
 
         self.cclasses_indices = markovchain.communication_classes_indices
         self.rclasses_indices = markovchain.recurrent_classes_indices
-        transient = set(list(map(tuple, self.cclasses_indices))).difference(
-            set(list(map(tuple, self.rclasses_indices)))
+        transient = set(map(tuple, self.cclasses_indices)).difference(
+            set(map(tuple, self.rclasses_indices))
         )
         self.num_tclasses = len(transient)
         if len(transient):
@@ -259,7 +260,7 @@ class Markov(object):
             if self.num_rclasses == 1:
                 print("1 Recurrent class (indices):")
             else:
-                print("{0} Recurrent classes (indices):".format(self.num_rclasses))
+                print(f"{self.num_rclasses} Recurrent classes (indices):")
             print(*self.rclasses_indices, sep=", ")
             if self.num_tclasses == 0:
                 print("0 Transient classes.")
@@ -267,7 +268,7 @@ class Markov(object):
                 if self.num_tclasses == 1:
                     print("1 Transient class (indices):")
                 else:
-                    print("{0} Transient classes (indices):".format(self.num_tclasses))
+                    print(f"{self.num_tclasses} Transient classes (indices):")
                 print(*self.tclasses_indices, sep=", ")
             if self.num_astates == 0:
                 print("The Markov Chain has 0 absorbing states.")
@@ -276,19 +277,11 @@ class Markov(object):
                     print("The Markov Chain has 1 absorbing state (index):")
                 else:
                     print(
-                        "The Markov Chain has {0} absorbing states (indices):".format(
-                            self.num_astates
-                        )
+                        f"The Markov Chain has {self.num_astates} "
+                        "absorbing states (indices):"
                     )
                 print(*self.astates_indices, sep=", ")
 
-    @property
-    def mfpt(self):
-        warn('self._mfpt is deprecated. Please use self._mfpt')
-        if not hasattr(self, "_mfpt"):
-            self._mfpt = mfpt(self.p, fill_empty_classes=True)
-        return self._mfpt
-
     @property
     def mfpt(self):
         if not hasattr(self, "_mfpt"):
@@ -308,7 +301,7 @@ class Markov(object):
         return self._st
 
 
-class Spatial_Markov(object):
+class Spatial_Markov:
     """
     Markov transitions conditioned on the value of the spatial lag.
 
@@ -551,7 +544,7 @@ class Spatial_Markov(object):
     the second quintile, 0.204 (0.190) in the third, 0.0684 (0.255) in the
     fourth and 0.029 (0.337) in the fifth quintile.
 
-    >>> sm.S
+    >>> sm.S.astype(float).round(8)
     array([[0.43509425, 0.2635327 , 0.20363044, 0.06841983, 0.02932278],
            [0.13391287, 0.33993305, 0.25153036, 0.23343016, 0.04119356],
            [0.12124869, 0.21137444, 0.2635101 , 0.29013417, 0.1137326 ],
@@ -567,7 +560,7 @@ class Spatial_Markov(object):
     fourth quintile after 28.473 years.
 
     >>> for f in sm.F:
-    ...     print(f)
+    ...     print(f.round(8))
     [[  2.29835259  28.95614035  46.14285714  80.80952381 279.42857143]
      [ 33.86549708   3.79459555  22.57142857  57.23809524 255.85714286]
      [ 43.60233918   9.73684211   4.91085714  34.66666667 233.28571429]
@@ -708,7 +701,9 @@ class Spatial_Markov(object):
     We can easily adjust this assigning `fill_empty_classes = True` when initializing
     `Spatial_Markov`.
 
-    >>> sm = Spatial_Markov(rpci, w, cutoffs=cc, lag_cutoffs=cc, fill_empty_classes=True)
+    >>> sm = Spatial_Markov(
+    ...     rpci, w, cutoffs=cc, lag_cutoffs=cc, fill_empty_classes=True
+    ... )
     >>> for p in sm.P:
     ...     print(p)
     [[0.96703297 0.03296703 0.         0.         0.        ]
@@ -800,7 +795,6 @@ class Spatial_Markov(object):
         variable_name=None,
         fill_empty_classes=False,
     ):
-
         y = np.asarray(y)
         self.fixed = fixed
         self.discrete = discrete
@@ -858,10 +852,10 @@ class Spatial_Markov(object):
     def S(self):
         if not hasattr(self, "_S"):
             _S = []
-            for i, p in enumerate(self.P):
+            for p in self.P:
                 _S.append(steady_state(p))
             # if np.array(_S).dtype is np.dtype('O'):
-            self._S = np.asarray(_S)
+            self._S = np.asarray(_S, dtype=object)
         return self._S
 
     @property
@@ -1076,7 +1070,7 @@ class Spatial_Markov(object):
 
 
 def chi2(T1, T2):
-    """
+    r"""
     chi-squared test of difference between two transition matrices.
 
     Parameters
@@ -1327,7 +1321,7 @@ class LISA_Markov(Markov):
     >>> lm_random.significant_moves[0, :3]
     array([11, 11, 11])
     >>> lm_random.significant_moves[0,-3:]
-    array([59, 43, 27])
+    array([59, 59, 43])
 
 
     Any value less than 49 indicates at least one of the LISA end points was
@@ -1536,8 +1530,8 @@ class LISA_Markov(Markov):
                             spill_ids.append(j)
                             break
                 for spill_id in spill_ids:
-                    id = self.w.id2i[spill_id]
-                    spill_over[id, t] = 1
+                    id_ = self.w.id2i[spill_id]
+                    spill_over[id_, t] = 1
                 for c, component in enumerate(components1):
                     for i in component:
                         ii = self.w.id2i[i]
@@ -1850,14 +1844,14 @@ class Homogeneity_Results:
         lead = "-" * width
         head = title.center(width)
         contents = [lead, head, lead]
-        l = "Number of regimes: %d" % int(self.m)
+        L = "Number of regimes: %d" % int(self.m)
         k = "Number of classes: %d" % int(self.k)
         r = "Regime names: "
         r += ", ".join(regime_names)
         t = "Number of transitions: %d" % int(self.t_total)
         contents.append(k)
         contents.append(t)
-        contents.append(l)
+        contents.append(L)
         contents.append(r)
         contents.append(lead)
         h = "%7s %20s %20s" % ("Test", "LR", "Chi-2")
@@ -1868,7 +1862,7 @@ class Homogeneity_Results:
         contents.append(stat)
         stat = "%7s %20.3f %20.3f" % ("p-value", self.LR_p_value, self.Q_p_value)
         contents.append(stat)
-        print(("\n".join(contents)))
+        print("\n".join(contents))
         print(lead)
 
         cols = ["P(%s)" % str(regime) for regime in self.regime_names]
@@ -1881,14 +1875,14 @@ class Homogeneity_Results:
         p0 = []
         line0 = ["{s: <{w}}".format(s="P(H0)", w=col_width)]
         line0.extend(
-            (["{s: >{w}}".format(s=cname, w=col_width) for cname in self.class_names])
+            ["{s: >{w}}".format(s=cname, w=col_width) for cname in self.class_names]
         )
-        print(("    ".join(line0)))
+        print("    ".join(line0))
         p0.append("&".join(line0))
         for i, row in enumerate(self.p_h0):
             line = ["%*s" % (col_width, str(self.class_names[i]))]
             line.extend(["%*.3f" % (col_width, v) for v in row])
-            print(("    ".join(line)))
+            print("    ".join(line))
             p0.append("&".join(line))
         pmats = [p0]
 
@@ -1897,19 +1891,14 @@ class Homogeneity_Results:
             p0 = []
             line0 = ["{s: <{w}}".format(s="P(%s)" % regime_names[r], w=col_width)]
             line0.extend(
-                (
-                    [
-                        "{s: >{w}}".format(s=cname, w=col_width)
-                        for cname in self.class_names
-                    ]
-                )
+                ["{s: >{w}}".format(s=cname, w=col_width) for cname in self.class_names]
             )
-            print(("    ".join(line0)))
+            print("    ".join(line0))
             p0.append("&".join(line0))
             for i, row in enumerate(p1):
                 line = ["%*s" % (col_width, str(self.class_names[i]))]
                 line.extend(["%*.3f" % (col_width, v) for v in row])
-                print(("    ".join(line)))
+                print("    ".join(line))
                 p0.append("&".join(line))
             pmats.append(p0)
             print(lead)
@@ -1917,7 +1906,7 @@ class Homogeneity_Results:
         if file_name:
             k = self.k
             ks = str(k + 1)
-            with open(file_name, "w") as f:
+            with open(file_name + ".tex", "w") as f:
                 c = []
                 fmt = "r" * (k + 1)
                 s = "\\begin{tabular}{|%s|}\\hline\n" % fmt
@@ -2038,14 +2027,13 @@ class FullRank_Markov(Markov):
     """
 
     def __init__(self, y, fill_empty_classes=False, summary=True):
-
         y = np.asarray(y)
         # resolve ties: All values are given a distinct rank, corresponding
         # to the order that the values occur in each cross section.
         r_asc = np.array([rankdata(col, method="ordinal") for col in y.T]).T
         # ranks by high (1) to low (n)
         self.ranks = r_asc.shape[0] - r_asc + 1
-        super(FullRank_Markov, self).__init__(
+        super().__init__(
             self.ranks, fill_empty_classes=fill_empty_classes, summary=summary
         )
 
@@ -2087,13 +2075,13 @@ def sojourn_time(p, summary=True):
     >>> sojourn_time(p)
     Sojourn times are infinite for absorbing states! In this Markov Chain, states [2] are absorbing states.
     array([ 2.,  1., inf])
-    """
+    """  # noqa E501
 
     p = np.asarray(p)
     if (p.sum(axis=1) == 0).sum() > 0:
         p = fill_empty_diagonals(p)
 
-    markovchain = qe.MarkovChain(p)
+    # markovchain = qe.MarkovChain(p)
     pii = p.diagonal()
 
     if not (1 - pii).all():
@@ -2103,9 +2091,7 @@ def sojourn_time(p, summary=True):
         if summary:
             print(
                 "Sojourn times are infinite for absorbing states! In this "
-                "Markov Chain, states {} are absorbing states.".format(
-                    list(absorbing_states)
-                )
+                f"Markov Chain, states {list(absorbing_states)} are absorbing states."
             )
         st[non_absorbing_states] = 1 / (1 - pii[non_absorbing_states])
     else:
@@ -2215,11 +2201,12 @@ class GeoRank_Markov(Markov):
 
     def __init__(self, y, fill_empty_classes=False, summary=True):
         y = np.asarray(y)
-        n = y.shape[0]
+        # n = y.shape[0]
+
         # resolve ties: All values are given a distinct rank, corresponding
         # to the order that the values occur in each cross section.
         ranks = np.array([rankdata(col, method="ordinal") for col in y.T]).T
         geo_ranks = np.argsort(ranks, axis=0) + 1
-        super(GeoRank_Markov, self).__init__(
+        super().__init__(
             geo_ranks, fill_empty_classes=fill_empty_classes, summary=summary
         )
